unit SoftekBarCode;

{ (c)2003 Marian Aldenhvel MBA Software-Consulting
  Rosenhain 23
  53123 Bonn

  marian@mba-software.de

  This unit dynamically imports the functions from the Softek Barcode Library.

  Usage:

  - Call InitSoftekLibrary from somewhere in your program before calling any of
  the functions.
  - See the documentation from Softek for the use of the actual functions.

  AJB: 7/6/05 - Added the stuff necessary for SkewTolerance.

  Joe Skeen 3-May-2010 - Added missing functions in the current toolkit
  jskeen@utah.gov   joe_skeen@hotmail.com

  AJB: 8/3/2012
  - converted "st" function to "mt" functions
  - added mtCreateBarcodeInstance and mtDestroyBarcodeInstance
  - changed short=shortint to short=smallint
  - added databar and qrcode functions

  AJB: 8/8/2023
  - Added the mtGetRawBarString function.
}

interface

uses
  Winapi.Windows,
  System.SysUtils;

type
  ESoftekBarCodeError = class(Exception);

  Short = SmallInt;
  Long = Integer;
  PLong = ^Long;

var
  mtCreateBarcodeInstance: function(): Pointer; stdcall;
  mtDestroyBarcodeInstance: function(hBarcode: Pointer): Integer; stdcall;
  mtGetBitmapResolution: function(hBarcode: Pointer): Integer; stdcall;
  mtSetBitmapResolution: function(hBarcode: Pointer; newValue: Integer): Integer; stdcall;
  mtGetDebugTraceFile: function(hBarcode: Pointer): PAnsiChar; stdcall;
  mtSetDebugTraceFile: function(hBarcode: Pointer; lpszNewValue: PAnsiChar): PAnsiChar; stdcall;
  mtSetLicenseKey: function(hBarcode: Pointer; lpszNewValue: PAnsiChar): PAnsiChar; stdcall;
  mtGetLineJump: function(hBarcode: Pointer): Integer; stdcall;
  mtSetLineJump: function(hBarcode: Pointer; nNewValue: Integer): Integer; stdcall;
  mtGetLowerRatio: function(hBarcode: Pointer): double; stdcall;
  mtSetLowerRatio: function(hBarcode: Pointer; newValue: double): double; stdcall;
  mtGetMinOccurrence: function(hBarcode: Pointer): Short; stdcall;
  mtSetMinOccurrence: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetMultipleRead: function(hBarcode: Pointer): bool; stdcall;
  mtSetMultipleRead: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetNoiseReduction: function(hBarcode: Pointer): Short; stdcall;
  mtSetNoiseReduction: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetPageNo: function(hBarcode: Pointer): Short; stdcall;
  mtSetPageNo: function(hBarcode: Pointer; nNewValue: Integer): Integer; stdcall;
  mtGetPrefOccurrence: function(hBarcode: Pointer): Short; stdcall;
  mtSetPrefOccurrence: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetQuietZoneSize: function(hBarcode: Pointer): Short; stdcall;
  mtSetQuietZoneSize: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetRotation: function(hBarcode: Pointer): Short; stdcall;
  mtSetRotation: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetUpperRatio: function(hBarcode: Pointer): double; stdcall;
  mtSetUpperRatio: function(hBarcode: Pointer; newValue: double): double; stdcall;
  mtGetReadCode39: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadCode39: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadPDF417: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadPDF417: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadEAN13: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadEAN13: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadEAN8: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadEAN8: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadUPCA: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadUPCA: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadUPCE: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadUPCE: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetShowCheckDigit: function(hBarcode: Pointer): bool; stdcall;
  mtSetShowCheckDigit: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadCode128: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadCode128: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetCode39NeedStartStop: function(hBarcode: Pointer): bool; stdcall;
  mtSetCode39NeedStartStop: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadCode25: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadCode25: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetColorThreshold: function(hBarcode: Pointer): Short; stdcall;
  mtSetColorThreshold: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetColorProcessingLevel: function(hBarcode: Pointer): Short; stdcall;
  mtSetColorProcessingLevel: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetBarString: function(hBarcode: Pointer; index: Short): PAnsiChar; stdcall;
  mtGetRawBarString: function(hBarcode: Pointer; index: Short; pBarCode: Pointer; length: Integer): Integer; stdcall;
  // stScanBarCode:function(hBarcode:Pointer;FileName:PChar):short; stdcall;
  mtScanBarCodeFromBitmap: function(hBarcode: Pointer; hBitmap: Long): Short; stdcall;
  mtScanBarCodeFromDIB: function(hBarcode: Pointer; hDib: Long): Short; stdcall;
  mtGetBarStringType: function(hBarcode: Pointer; index: Short): PAnsiChar; stdcall;
  mtGetBarStringPos: function(hBarcode: Pointer; nBarCode: Short; var pTopLeftX, pTopLeftY, pBotRightX, pBotRightY: Long): Short; stdcall;
  mtSetScanRect: function(hBarcode: Pointer; TopLeftX, TopLeftY, BottomRightX, BottomRightY: Long; MappingMode: Short): bool; stdcall;
  mtGetReadPatchCodes: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadPatchCodes: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  stSaveBitmap: function(hBarcode: Pointer; hBitmap: Long; strFilePath: PAnsiChar): bool; stdcall;
  { DT 09/06/04 }
  mtGetReadCodabar: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadCodabar: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetMaxLength: function(hBarcode: Pointer): Short; stdcall;
  mtSetMaxLength: function(hBarcode: Pointer; nNewValue: Integer): Short; stdcall;
  mtGetMinLength: function(hBarcode: Pointer): Short; stdcall;
  mtSetMinLength: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtGetScanDirection: function(hBarcode: Pointer): Short; stdcall;
  mtSetScanDirection: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  { AJB 7/4/05 }
  mtGetSkewTolerance: function(hBarcode: Pointer): Short; stdcall;
  mtSetSkewTolerance: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  { Joe Skeen 3-May-2010 }  // missing functions - some don't show in the documentation yet.
  mtScanBarCode: function(hBarcode: Pointer; FileName: PAnsiChar): Short; stdcall;
  // corrected for use with unicode or non-unicode versions of Delphi
  mtGetBarCodeConfidence: function(hBarcode: Pointer; nBarCode: Short): Short; stdcall;
  mtGetReadDataMatrix: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadDataMatrix: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetConvertUPCEToEAN13: function(hBarcode: Pointer): bool; stdcall;
  mtSetConvertUPCEToEAN13: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  // stConvertCode39Extended
  mtExportXMLSettings: function(hBarcode: Pointer; var filePath: PAnsiChar): Integer; stdcall;
  mtGetAllowDuplicateValues: function(hBarcode: Pointer): bool; stdcall;
  // mtGetBarStringA
  mtGetBarStringDirection: function(hBarcode: Pointer; nBarCode: Short): Short; stdcall;
  mtGetCode25Checksum: function(hBarcode: Pointer): bool; stdcall;
  mtGetCode39Checksum: function(hBarcode: Pointer): bool; stdcall;
  mtGetDespeckle: function(hBarcode: Pointer): bool; stdcall;
  mtGetEncoding: function(hBarcode: Pointer): Short; stdcall;
  mtGetErrorCorrection: function(hBarcode: Pointer): bool; stdcall;
  mtGetExtendedCode39: function(hBarcode: Pointer): bool; stdcall;
  mtGetGammaCorrection: function(hBarcode: Pointer): Short; stdcall;
  mtGetMedianFilter: function(hBarcode: Pointer): bool; stdcall;
  mtGetMinSeparation: function(hBarcode: Pointer): Short; stdcall;
  mtGetMinSpaceBarWidth: function(hBarcode: Pointer): Short; stdcall;
  mtGetPattern: function(hBarcode: Pointer): PAnsiChar; stdcall;
  // mtGetPDFTool
  mtGetPdfBpp: function(hBarcode: Pointer): Short; stdcall;
  mtGetPdfDpi: function(hBarcode: Pointer): Short; stdcall;
  mtGetPhotometric: function(hBarcode: Pointer): bool; stdcall;
  mtGetReadCode25ni: function(hBarcode: Pointer): bool; stdcall;
  mtGetReadMicroPDF417: function(hBarcode: Pointer): bool; stdcall;
  mtGetReadNumeric: function(hBarcode: Pointer): bool; stdcall;
  mtGetReadShortCode128: function(hBarcode: Pointer): bool; stdcall;
  mtGetShortCode128MinLength: function(hBarcode: Pointer): Short; stdcall;
  mtGetSkewLineJump: function(hBarcode: Pointer): Short; stdcall;
  mtGetTifSplitMode: function(hBarcode: Pointer): Short; stdcall;
  mtGetTifSplitPath: function(hBarcode: Pointer): PAnsiChar; stdcall;
  mtGetUseOverSampling: function(hBarcode: Pointer): bool; stdcall;
  mtLoadXMLSettings: function(hBarcode: Pointer; filePath: PAnsiChar; silent: Byte): Integer; stdcall;
  mtProcessXML: function(hBarcode: Pointer; inputFilePath: PAnsiChar; outputFilePath: PAnsiChar; silent: Byte): Integer; stdcall;
  mtSaveResults: function(hBarcode: Pointer; filePath: PAnsiChar): Integer; stdcall;
  mtSetAllowDuplicateValues: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetCode25Checksum: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetCode39Checksum: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetDespeckle: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetEncoding: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetErrorCorrection: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetExtendedCode39: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetGammaCorrection: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetMedianFilter: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetMinSeparation: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetMinSpaceBarWidth: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetPattern: function(hBarcode: Pointer; lpszNewValue: PAnsiChar): PAnsiChar; stdcall;
  mtSetPdfBpp: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetPdfDpi: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  mtSetPhotometric: function(hBarcode: Pointer; bPhotometric: bool): bool; stdcall;
  mtSetReadCode25ni: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetReadMicroPDF417: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetReadNumeric: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetReadShortCode128: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetShortCode128MinLength: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetSkewLineJump: function(hBarcode: Pointer; nNewValue: Short): Short; stdcall;
  // mtSetTempFolder
  mtSetTifSplitMode: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetTifSplitPath: function(hBarcode: Pointer; szPath: PAnsiChar): PAnsiChar; stdcall;
  mtSetUseOverSampling: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  // AJB - new functions added 8/3/2012
  mtSetReadDatabar: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadDatabar: function(hBarcode: Pointer): bool; stdcall;
  mtSetReadQRCode: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetReadQRCode: function(hBarcode: Pointer): bool; stdcall;
  mtSetDatabarOptions: function(hBarcode: Pointer; iNewValue: Integer): Short; stdcall;
  mtGetDatabarOptions: function(hBarcode: Pointer): Short; stdcall;
  mtSetPdfImageOnly: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetPdfImageOnly: function(hBarcode: Pointer): bool; stdcall;
  mtSetPdfImageExtractOptions: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtGetPdfImageExtractOptions: function(hBarcode: Pointer): Short; stdcall;
  mtSetPdfImageRasterOptions: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtGetPdfImageRasterOptions: function(hBarcode: Pointer): Short; stdcall;
  // AJB - new functions added 2/10/2017
  mtGetBarcodesAtTopOfPage: function(hBarcode: Pointer): bool; stdcall;
  mtGetCode128Lenient: function(hBarcode: Pointer): bool; stdcall;
  mtGetDataMatrixAutoUTF8: function(hBarcode: Pointer): bool; stdcall;
  mtGetPdf417AutoUTF8: function(hBarcode: Pointer): bool; stdcall;
  mtGetPdf417Debug: function(hBarcode: Pointer): bool; stdcall;
  mtGetPdf417MacroEscapeBackslash: function(hBarcode: Pointer): bool; stdcall;
  mtGetQRCodeAutoMedianFilter: function(hBarcode: Pointer): bool; stdcall;
  mtGetQRCodeAutoUTF8: function(hBarcode: Pointer): bool; stdcall;
  mtGetQrCodeReadInverted: function(hBarcode: Pointer): bool; stdcall;
  mtGetReadCode93: function(hBarcode: Pointer): bool; stdcall;
  mtGetRotateBy45IfNoBarcode: function(hBarcode: Pointer): bool; stdcall;
  mtGetSkewedDatamatrix: function(hBarcode: Pointer): bool; stdcall;
  mtGetSkewedLinear: function(hBarcode: Pointer): bool; stdcall;
  mtGetUseFastScan: function(hBarcode: Pointer): bool; stdcall;
  mtGetUseOldCode128Algorithm: function(hBarcode: Pointer): bool; stdcall;
  mtGetUseRunCache: function(hBarcode: Pointer): bool; stdcall;
  mtGetWeightLongerBarcodes: function(hBarcode: Pointer): bool; stdcall;
  mtSetBarcodesAtTopOfPage: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetCode128Lenient: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetDataMatrixAutoUTF8: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetPdf417AutoUTF8: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetPdf417Debug: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetPdf417MacroEscapeBackslash: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetQRCodeAutoMedianFilter: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetQRCodeAutoUTF8: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetQrCodeReadInverted: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetReadCode93: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetRotateBy45IfNoBarcode: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetSkewedDatamatrix: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetSkewedLinear: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetUseFastScan: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetUseOldCode128Algorithm: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetUseRunCache: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtSetWeightLongerBarcodes: function(hBarcode: Pointer; bNewValue: bool): bool; stdcall;
  mtGetBarCodeCount: function(hBarcode: Pointer): Short; stdcall;
  mtGetCode128DebugMode: function(hBarcode: Pointer): Short; stdcall;
  mtGetCode128SearchLevel: function(hBarcode: Pointer): Short; stdcall;
  mtGetCode39MaxRatioPcnt: function(hBarcode: Pointer): Short; stdcall;
  mtGetDataMatrixFinderGapTolerance: function(hBarcode: Pointer): Short; stdcall;
  mtGetFastScanLineJump: function(hBarcode: Pointer): Short; stdcall;
  mtGetMaxBarcodesPerPage: function(hBarcode: Pointer): Short; stdcall;
  mtGetMaxThreads: function(hBarcode: Pointer): Short; stdcall;
  mtGetMedianFilterBias: function(hBarcode: Pointer): Short; stdcall;
  mtGetPatchCodeMinOccurrence: function(hBarcode: Pointer): Short; stdcall;
  mtGetPdf417ChannelMode: function(hBarcode: Pointer): Short; stdcall;
  mtGetPdfLocking: function(hBarcode: Pointer): Short; stdcall;
  mtGetQuotedPrintableCharSet: function(hBarcode: Pointer): Short; stdcall;
  mtGetReportUnreadBarcodes: function(hBarcode: Pointer): Short; stdcall;
  mtGetShowCodabarStartStop: function(hBarcode: Pointer): Short; stdcall;
  // QWERTY
  mtGetBarStringPage: function(hBarcode: Pointer; index: Short): Integer; stdcall;
  mtGetBarStringQualityScore: function(hBarcode: Pointer; index: Short): Short; stdcall;
  mtGetLastError: function(hBarcode: Pointer): Integer; stdcall;
  mtGetLastWinError: function(hBarcode: Pointer): Integer; stdcall;
  mtGetLicenseKey: function(hBarcode: Pointer): PAnsiChar; stdcall;
  mtGetProgress: function(hBarcode: Pointer): Integer; stdcall;
  mtGetScanExitCode: function(hBarcode: Pointer): Integer; stdcall;
  mtGetTimeOut: function(hBarcode: Pointer): Integer; stdcall;
  mtScanBarCodeAbort: function(hBarcode: Pointer): Short; stdcall;
  mtScanBarCodeInBackground: function(hBarcode: Pointer; FileName: PAnsiChar): Short; stdcall;
  mtScanBarCodeWait: function(hBarcode: Pointer; milliSeconds: Integer): Short; stdcall;
  mtSetCode128DebugMode: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetCode128SearchLevel: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetCode39MaxRatioPcnt: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetDataMatrixFinderGapTolerance: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetFastScanLineJump: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetMaxBarcodesPerPage: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetMaxThreads: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetMedianFilterBias: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetPatchCodeMinOccurrence: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetPdf417ChannelMode: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetPdfLocking: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetQuotedPrintableCharSet: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetReportUnreadBarcodes: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetShowCodabarStartStop: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtSetTimeOut: function(hBarcode: Pointer; sNewValue: Integer): Integer; stdcall;
  // AJB - new functions added 16/04/2020
  mtSetPdfPassword: function(hBarcode: Pointer; lpszNewValue: PAnsiChar): PAnsiChar; stdcall;
  mtGetPdfPassword: function(hBarcode: Pointer): PAnsiChar; stdcall;
  mtSetDataMatrixSearchLevel: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtGetDataMatrixSearchLevel: function(hBarcode: Pointer): Short; stdcall;
  mtSetDataMatrixRectangleSupport: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtGetDataMatrixRectangleSupport: function(hBarcode: Pointer): Short; stdcall;
  mtSetReadEAN13Supplemental: function(hBarcode: Pointer; sNewValue: bool): bool; stdcall;
  mtGetReadEAN13Supplemental: function(hBarcode: Pointer): bool; stdcall;
  mtSetDeskewMode: function(hBarcode: Pointer; sNewValue: Short): Short; stdcall;
  mtGetDeskewMode: function(hBarcode: Pointer): Short; stdcall;

function stGetErrorString(ErrorCode: Integer): string;
function InitSoftekLibrary(dllPath: String): boolean;
procedure DoneLibrary;

implementation

var
  LibraryHandle: THandle = 0;

function stGetErrorString(ErrorCode: Integer): string;
begin
  case ErrorCode of
    - 1:
      Result := 'Error opening file';
    -2:
      Result := 'File is Multi Plane';
    -3:
      Result := 'Invalid number of bits per sample';
    -4:
      Result := 'Memory allocation error';
    -5:
      Result := 'Invalid TIF photometric value';
    -6, -7, -8:
      Result := 'The trial period on a demo version has either expired or this trial version is no longer valid for installation.';
  else
    Result := Format('Unknown error %d', [ErrorCode]);
  end;
end;

function InitSoftekLibrary(dllPath: String): boolean;

  function DoGetProcAddress(aName: string): Pointer;
  begin
    Result := GetProcAddress(LibraryHandle, PChar(aName));
    // if Result=NIL then RaiseLastOSError;
  end;

begin
  Result := true;
  if LibraryHandle = 0 then
  begin
    LibraryHandle := LoadLibrary(PChar(dllPath));
    if LibraryHandle > 0 then
    begin
      @mtGetLineJump := DoGetProcAddress('mtGetLineJump');
      @mtGetBitmapResolution := DoGetProcAddress('mtGetBitmapResolution');
      @mtSetBitmapResolution := DoGetProcAddress('mtSetBitmapResolution');
      @mtGetDebugTraceFile := DoGetProcAddress('mtGetDebugTraceFile');
      @mtSetDebugTraceFile := DoGetProcAddress('mtSetDebugTraceFile');
      @mtSetLicenseKey := DoGetProcAddress('mtSetLicenseKey');
      @mtGetLineJump := DoGetProcAddress('mtGetLineJump');
      @mtSetLineJump := DoGetProcAddress('mtSetLineJump');
      @mtGetLowerRatio := DoGetProcAddress('mtGetLowerRatio');
      @mtSetLowerRatio := DoGetProcAddress('mtSetLowerRatio');
      @mtGetMinOccurrence := DoGetProcAddress('mtGetMinOccurrence');
      @mtSetMinOccurrence := DoGetProcAddress('mtSetMinOccurrence');
      @mtGetMultipleRead := DoGetProcAddress('mtGetMultipleRead');
      @mtSetMultipleRead := DoGetProcAddress('mtSetMultipleRead');
      @mtGetNoiseReduction := DoGetProcAddress('mtGetNoiseReduction');
      @mtSetNoiseReduction := DoGetProcAddress('mtSetNoiseReduction');
      @mtGetPageNo := DoGetProcAddress('mtGetPageNo');
      @mtSetPageNo := DoGetProcAddress('mtSetPageNo');
      @mtGetPrefOccurrence := DoGetProcAddress('mtGetPrefOccurrence');
      @mtSetPrefOccurrence := DoGetProcAddress('mtSetPrefOccurrence');
      @mtGetQuietZoneSize := DoGetProcAddress('mtGetQuietZoneSize');
      @mtSetQuietZoneSize := DoGetProcAddress('mtSetQuietZoneSize');
      @mtGetRotation := DoGetProcAddress('mtGetRotation');
      @mtSetRotation := DoGetProcAddress('mtSetRotation');
      @mtGetUpperRatio := DoGetProcAddress('mtGetUpperRatio');
      @mtSetUpperRatio := DoGetProcAddress('mtSetUpperRatio');
      @mtGetReadCode39 := DoGetProcAddress('mtGetReadCode39');
      @mtSetReadCode39 := DoGetProcAddress('mtSetReadCode39');
      @mtGetReadEAN13 := DoGetProcAddress('mtGetReadEAN13');
      @mtSetReadEAN13 := DoGetProcAddress('mtSetReadEAN13');
      @mtGetReadEAN8 := DoGetProcAddress('mtGetReadEAN8');
      @mtSetReadEAN8 := DoGetProcAddress('mtSetReadEAN8');
      @mtGetReadUPCA := DoGetProcAddress('mtGetReadUPCA');
      @mtSetReadUPCA := DoGetProcAddress('mtSetReadUPCA');
      @mtGetReadUPCE := DoGetProcAddress('mtGetReadUPCE');
      @mtSetReadUPCE := DoGetProcAddress('mtSetReadUPCE');
      @mtGetShowCheckDigit := DoGetProcAddress('mtGetShowCheckDigit');
      @mtSetShowCheckDigit := DoGetProcAddress('mtSetShowCheckDigit');
      @mtGetReadCode128 := DoGetProcAddress('mtGetReadCode128');
      @mtSetReadCode128 := DoGetProcAddress('mtSetReadCode128');
      @mtGetCode39NeedStartStop := DoGetProcAddress('mtGetCode39NeedStartStop');
      @mtSetCode39NeedStartStop := DoGetProcAddress('mtSetCode39NeedStartStop');
      @mtGetReadCode25 := DoGetProcAddress('mtGetReadCode25');
      @mtSetReadCode25 := DoGetProcAddress('mtSetReadCode25');
      @mtGetColorThreshold := DoGetProcAddress('mtGetColorThreshold');
      @mtSetColorThreshold := DoGetProcAddress('mtSetColorThreshold');
      @mtGetColorProcessingLevel := DoGetProcAddress('mtGetColorProcessingLevel');
      @mtSetColorProcessingLevel := DoGetProcAddress('mtSetColorProcessingLevel');
      @mtGetBarString := DoGetProcAddress('mtGetBarString');
      @mtGetRawBarString := DoGetProcAddress('mtGetRawBarString');
      @mtScanBarCode := DoGetProcAddress('mtScanBarCode');
      @mtScanBarCodeFromBitmap := DoGetProcAddress('mtScanBarCodeFromBitmap');
      @mtScanBarCodeFromDIB := DoGetProcAddress('mtScanBarCodeFromDIB');
      @mtGetBarStringType := DoGetProcAddress('mtGetBarStringType');
      @mtGetBarStringPos := DoGetProcAddress('mtGetBarStringPos');
      @mtSetScanRect := DoGetProcAddress('mtSetScanRect');
      @mtGetReadPatchCodes := DoGetProcAddress('mtGetReadPatchCodes');
      @mtSetReadPatchCodes := DoGetProcAddress('mtSetReadPatchCodes');
      { DT 09/06/04 }
      @mtGetReadCodabar := DoGetProcAddress('mtGetReadCodabar');
      @mtSetReadCodabar := DoGetProcAddress('mtSetReadCodabar');
      @mtGetMaxLength := DoGetProcAddress('mtGetMaxLength');
      @mtSetMaxLength := DoGetProcAddress('mtSetMaxLength');
      @mtGetMinLength := DoGetProcAddress('mtGetMinLength');
      @mtSetMinLength := DoGetProcAddress('mtSetMinLength');
      @mtGetScanDirection := DoGetProcAddress('mtGetScanDirection');
      @mtSetScanDirection := DoGetProcAddress('mtSetScanDirection');
      { AJB 7/6/05 }
      @mtGetSkewTolerance := DoGetProcAddress('mtGetSkewTolerance');
      @mtSetSkewTolerance := DoGetProcAddress('mtSetSkewTolerance');
      { Joe Skeen 3-May-2010 }
      @mtGetBarCodeConfidence := DoGetProcAddress('mtGetBarCodeConfidence');
      @mtGetReadDataMatrix := DoGetProcAddress('mtGetReadDataMatrix');
      @mtSetReadDataMatrix := DoGetProcAddress('mtSetReadDataMatrix');
      @mtGetReadPDF417 := DoGetProcAddress('mtGetReadPDF417');
      @mtSetReadPDF417 := DoGetProcAddress('mtSetReadPDF417');
      @mtGetConvertUPCEToEAN13 := DoGetProcAddress('mtGetConvertUPCEToEAN13');
      @mtSetConvertUPCEToEAN13 := DoGetProcAddress('mtSetConvertUPCEToEAN13');
      @mtExportXMLSettings := DoGetProcAddress('mtExportXMLSettings');
      @mtGetAllowDuplicateValues := DoGetProcAddress('mtGetAllowDuplicateValues');
      @mtGetBarStringDirection := DoGetProcAddress('mtGetBarStringDirection');
      @mtGetCode25Checksum := DoGetProcAddress('mtGetCode25Checksum');
      @mtGetCode39Checksum := DoGetProcAddress('mtGetCode39Checksum');
      @mtGetDespeckle := DoGetProcAddress('mtGetDespeckle');
      @mtGetEncoding := DoGetProcAddress('mtGetEncoding');
      @mtGetErrorCorrection := DoGetProcAddress('mtGetErrorCorrection');
      @mtGetExtendedCode39 := DoGetProcAddress('mtGetExtendedCode39');
      @mtGetGammaCorrection := DoGetProcAddress('mtGetGammaCorrection');
      @mtGetMedianFilter := DoGetProcAddress('mtGetMedianFilter');
      @mtGetMinSeparation := DoGetProcAddress('mtGetMinSeparation');
      @mtGetMinSpaceBarWidth := DoGetProcAddress('mtGetMinSpaceBarWidth');
      @mtGetPattern := DoGetProcAddress('mtGetPattern');
      @mtGetPdfBpp := DoGetProcAddress('mtGetPdfBpp');
      @mtGetPdfDpi := DoGetProcAddress('mtGetPdfDpi');
      @mtGetPhotometric := DoGetProcAddress('mtGetPhotometric');
      @mtGetReadCode25ni := DoGetProcAddress('mtGetReadCode25ni');
      @mtGetReadMicroPDF417 := DoGetProcAddress('mtGetReadMicroPDF417');
      @mtGetReadNumeric := DoGetProcAddress('mtGetReadNumeric');
      @mtGetReadShortCode128 := DoGetProcAddress('mtGetReadShortCode128');
      @mtGetShortCode128MinLength := DoGetProcAddress('mtGetShortCode128MinLength');
      @mtGetSkewLineJump := DoGetProcAddress('mtGetSkewLineJump');
      @mtGetTifSplitMode := DoGetProcAddress('mtGetTifSplitMode');
      @mtGetTifSplitPath := DoGetProcAddress('mtGetTifSplitPath');
      @mtGetUseOverSampling := DoGetProcAddress('mtGetUseOverSampling');
      @mtLoadXMLSettings := DoGetProcAddress('mtLoadXMLSettings');
      @mtProcessXML := DoGetProcAddress('mtProcessXML');
      @mtSaveResults := DoGetProcAddress('mtSaveResults');
      @mtSetAllowDuplicateValues := DoGetProcAddress('mtSetAllowDuplicateValues');
      @mtSetCode25Checksum := DoGetProcAddress('mtSetCode25Checksum');
      @mtSetCode39Checksum := DoGetProcAddress('mtSetCode39Checksum');
      @mtSetDespeckle := DoGetProcAddress('mtSetDespeckle');
      @mtSetEncoding := DoGetProcAddress('mtSetEncoding');
      @mtSetErrorCorrection := DoGetProcAddress('mtSetErrorCorrection');
      @mtSetExtendedCode39 := DoGetProcAddress('mtSetExtendedCode39');
      @mtSetGammaCorrection := DoGetProcAddress('mtSetGammaCorrection');
      @mtSetMedianFilter := DoGetProcAddress('mtSetMedianFilter');
      @mtSetMinSeparation := DoGetProcAddress('mtSetMinSeparation');
      @mtSetMinSpaceBarWidth := DoGetProcAddress('mtSetMinSpaceBarWidth');
      @mtSetPattern := DoGetProcAddress('mtSetPattern');
      @mtSetPdfBpp := DoGetProcAddress('mtSetPdfBpp');
      @mtSetPdfDpi := DoGetProcAddress('mtSetPdfDpi');
      @mtSetPhotometric := DoGetProcAddress('mtSetPhotometric');
      @mtSetReadCode25ni := DoGetProcAddress('mtSetReadCode25ni');
      @mtSetReadMicroPDF417 := DoGetProcAddress('mtSetReadMicroPDF417');
      @mtSetReadNumeric := DoGetProcAddress('mtSetReadNumeric');
      @mtSetReadShortCode128 := DoGetProcAddress('mtSetReadShortCode128');
      @mtSetShortCode128MinLength := DoGetProcAddress('mtSetShortCode128MinLength');
      @mtSetSkewLineJump := DoGetProcAddress('mtSetSkewLineJump');
      @mtSetTifSplitMode := DoGetProcAddress('mtSetTifSplitMode');
      @mtSetTifSplitPath := DoGetProcAddress('mtSetTifSplitPath');
      @mtSetUseOverSampling := DoGetProcAddress('mtSetUseOverSampling');
      { AJB - new functions added 8/3/2012 }
      @mtSetReadDatabar := DoGetProcAddress('mtSetReadDatabar');
      @mtGetReadDatabar := DoGetProcAddress('mtGetReadDatabar');
      @mtSetReadQRCode := DoGetProcAddress('mtSetReadQRCode');
      @mtGetReadQRCode := DoGetProcAddress('mtGetReadQRCode');
      @mtSetDatabarOptions := DoGetProcAddress('mtSetDatabarOptions');
      @mtGetDatabarOptions := DoGetProcAddress('mtGetDatabarOptions');
      @mtSetPdfImageOnly := DoGetProcAddress('mtSetPdfImageOnly');
      @mtGetPdfImageOnly := DoGetProcAddress('mtGetPdfImageOnly');
      @mtSetPdfImageExtractOptions := DoGetProcAddress('mtSetPdfImageExtractOptions');
      @mtGetPdfImageExtractOptions := DoGetProcAddress('mtGetPdfImageExtractOptions');
      @mtSetPdfImageRasterOptions := DoGetProcAddress('mtSetPdfImageRasterOptions');
      @mtGetPdfImageRasterOptions := DoGetProcAddress('mtGetPdfImageRasterOptions');
      @mtCreateBarcodeInstance := DoGetProcAddress('mtCreateBarcodeInstance');
      @mtDestroyBarcodeInstance := DoGetProcAddress('mtDestroyBarcodeInstance');
      { AJB - new functions added 2/10/2017 }
      @mtGetBarcodesAtTopOfPage := DoGetProcAddress('mtGetBarcodesAtTopOfPage');
      @mtGetCode128Lenient := DoGetProcAddress('mtGetCode128Lenient');
      @mtGetDataMatrixAutoUTF8 := DoGetProcAddress('mtGetDataMatrixAutoUTF8');
      @mtGetPdf417AutoUTF8 := DoGetProcAddress('mtGetPdf417AutoUTF8');
      @mtGetPdf417Debug := DoGetProcAddress('mtGetPdf417Debug');
      @mtGetPdf417MacroEscapeBackslash := DoGetProcAddress('mtGetPdf417MacroEscapeBackslash');
      @mtGetQRCodeAutoMedianFilter := DoGetProcAddress('mtGetQRCodeAutoMedianFilter');
      @mtGetQRCodeAutoUTF8 := DoGetProcAddress('mtGetQRCodeAutoUTF8');
      @mtGetQrCodeReadInverted := DoGetProcAddress('mtGetQrCodeReadInverted');
      @mtGetReadCode93 := DoGetProcAddress('mtGetReadCode93');
      @mtGetRotateBy45IfNoBarcode := DoGetProcAddress('mtGetRotateBy45IfNoBarcode');
      @mtGetSkewedDatamatrix := DoGetProcAddress('mtGetSkewedDatamatrix');
      @mtGetSkewedLinear := DoGetProcAddress('mtGetSkewedLinear');
      @mtGetUseFastScan := DoGetProcAddress('mtGetUseFastScan');
      @mtGetUseOldCode128Algorithm := DoGetProcAddress('mtGetUseOldCode128Algorithm');
      @mtGetUseRunCache := DoGetProcAddress('mtGetUseRunCache');
      @mtGetWeightLongerBarcodes := DoGetProcAddress('mtGetWeightLongerBarcodes');
      @mtSetBarcodesAtTopOfPage := DoGetProcAddress('mtSetBarcodesAtTopOfPage');
      @mtSetCode128Lenient := DoGetProcAddress('mtSetCode128Lenient');
      @mtSetDataMatrixAutoUTF8 := DoGetProcAddress('mtSetDataMatrixAutoUTF8');
      @mtSetPdf417AutoUTF8 := DoGetProcAddress('mtSetPdf417AutoUTF8');
      @mtSetPdf417Debug := DoGetProcAddress('mtSetPdf417Debug');
      @mtSetPdf417MacroEscapeBackslash := DoGetProcAddress('mtSetPdf417MacroEscapeBackslash');
      @mtSetQRCodeAutoMedianFilter := DoGetProcAddress('mtSetQRCodeAutoMedianFilter');
      @mtSetQRCodeAutoUTF8 := DoGetProcAddress('mtSetQRCodeAutoUTF8');
      @mtSetQrCodeReadInverted := DoGetProcAddress('mtSetQrCodeReadInverted');
      @mtSetReadCode93 := DoGetProcAddress('mtSetReadCode93');
      @mtSetRotateBy45IfNoBarcode := DoGetProcAddress('mtSetRotateBy45IfNoBarcode');
      @mtSetSkewedDatamatrix := DoGetProcAddress('mtSetSkewedDatamatrix');
      @mtSetSkewedLinear := DoGetProcAddress('mtSetSkewedLinear');
      @mtSetUseFastScan := DoGetProcAddress('mtSetUseFastScan');
      @mtSetUseOldCode128Algorithm := DoGetProcAddress('mtSetUseOldCode128Algorithm');
      @mtSetUseRunCache := DoGetProcAddress('mtSetUseRunCache');
      @mtSetWeightLongerBarcodes := DoGetProcAddress('mtSetWeightLongerBarcodes');
      @mtGetBarCodeCount := DoGetProcAddress('mtGetBarCodeCount');
      @mtGetCode128DebugMode := DoGetProcAddress('mtGetCode128DebugMode');
      @mtGetCode128SearchLevel := DoGetProcAddress('mtGetCode128SearchLevel');
      @mtGetCode39MaxRatioPcnt := DoGetProcAddress('mtGetCode39MaxRatioPcnt');
      @mtGetDataMatrixFinderGapTolerance := DoGetProcAddress('mtGetDataMatrixFinderGapTolerance');
      @mtGetFastScanLineJump := DoGetProcAddress('mtGetFastScanLineJump');
      @mtGetMaxBarcodesPerPage := DoGetProcAddress('mtGetMaxBarcodesPerPage');
      @mtGetMaxThreads := DoGetProcAddress('mtGetMaxThreads');
      @mtGetMedianFilterBias := DoGetProcAddress('mtGetMedianFilterBias');
      @mtGetPatchCodeMinOccurrence := DoGetProcAddress('mtGetPatchCodeMinOccurrence');
      @mtGetPdf417ChannelMode := DoGetProcAddress('mtGetPdf417ChannelMode');
      @mtGetPdfLocking := DoGetProcAddress('mtGetPdfLocking');
      @mtGetQuotedPrintableCharSet := DoGetProcAddress('mtGetQuotedPrintableCharSet');
      @mtGetReportUnreadBarcodes := DoGetProcAddress('mtGetReportUnreadBarcodes');
      @mtGetShowCodabarStartStop := DoGetProcAddress('mtGetShowCodabarStartStop');
      @mtGetBarStringPage := DoGetProcAddress('mtGetBarStringPage');
      @mtGetBarStringQualityScore := DoGetProcAddress('mtGetBarStringQualityScore');
      @mtGetLastError := DoGetProcAddress('mtGetLastError');
      @mtGetLastWinError := DoGetProcAddress('mtGetLastWinError');
      @mtGetLicenseKey := DoGetProcAddress('mtGetLicenseKey');
      @mtGetProgress := DoGetProcAddress('mtGetProgress');
      @mtGetScanExitCode := DoGetProcAddress('mtGetScanExitCode');
      @mtGetTimeOut := DoGetProcAddress('mtGetTimeOut');
      @mtScanBarCodeAbort := DoGetProcAddress('mtScanBarCodeAbort');
      @mtScanBarCodeInBackground := DoGetProcAddress('mtScanBarCodeInBackground');
      @mtScanBarCodeWait := DoGetProcAddress('mtScanBarCodeWait');
      @mtSetCode128DebugMode := DoGetProcAddress('mtSetCode128DebugMode');
      @mtSetCode128SearchLevel := DoGetProcAddress('mtSetCode128SearchLevel');
      @mtSetCode39MaxRatioPcnt := DoGetProcAddress('mtSetCode39MaxRatioPcnt');
      @mtSetDataMatrixFinderGapTolerance := DoGetProcAddress('mtSetDataMatrixFinderGapTolerance');
      @mtSetFastScanLineJump := DoGetProcAddress('mtSetFastScanLineJump');
      @mtSetMaxBarcodesPerPage := DoGetProcAddress('mtSetMaxBarcodesPerPage');
      @mtSetMaxThreads := DoGetProcAddress('mtSetMaxThreads');
      @mtSetMedianFilterBias := DoGetProcAddress('mtSetMedianFilterBias');
      @mtSetPatchCodeMinOccurrence := DoGetProcAddress('mtSetPatchCodeMinOccurrence');
      @mtSetPdf417ChannelMode := DoGetProcAddress('mtSetPdf417ChannelMode');
      @mtSetPdfLocking := DoGetProcAddress('mtSetPdfLocking');
      @mtSetQuotedPrintableCharSet := DoGetProcAddress('mtSetQuotedPrintableCharSet');
      @mtSetReportUnreadBarcodes := DoGetProcAddress('mtSetReportUnreadBarcodes');
      @mtSetShowCodabarStartStop := DoGetProcAddress('mtSetShowCodabarStartStop');
      @mtSetTimeOut := DoGetProcAddress('mtSetTimeOut');
      { AJB - new functions added 16/04/2020 }
      @mtSetPdfPassword := DoGetProcAddress('mtSetPdfPassword');
      @mtGetPdfPassword := DoGetProcAddress('mtGetPdfPassword');
      @mtSetDataMatrixSearchLevel := DoGetProcAddress('mtSetDataMatrixSearchLevel');
      @mtGetDataMatrixSearchLevel := DoGetProcAddress('mtGetDataMatrixSearchLevel');
      @mtSetDataMatrixRectangleSupport := DoGetProcAddress('mtSetDataMatrixRectangleSupport');
      @mtGetDataMatrixRectangleSupport := DoGetProcAddress('mtGetDataMatrixRectangleSupport');
      @mtSetReadEAN13Supplemental := DoGetProcAddress('mtSetReadEAN13Supplemental');
      @mtGetReadEAN13Supplemental := DoGetProcAddress('mtGetReadEAN13Supplemental');
      @mtSetDeskewMode := DoGetProcAddress('mtSetDeskewMode');
      @mtGetDeskewMode := DoGetProcAddress('mtGetDeskewMode');
    end
    else
    begin
      Result := false;
    end;
  end;
end;

procedure DoneLibrary;
begin
  if LibraryHandle = 0 then
    exit;

  // if not FreeLibrary(LibraryHandle) then RaiseLastOSError;
  FreeLibrary(LibraryHandle);

  mtGetBitmapResolution := NIL;
  mtSetBitmapResolution := NIL;
  mtGetDebugTraceFile := NIL;
  mtSetDebugTraceFile := NIL;
  mtSetLicenseKey := NIL;
  mtGetLineJump := NIL;
  mtSetLineJump := NIL;
  mtGetLowerRatio := NIL;
  mtSetLowerRatio := NIL;
  mtGetMinOccurrence := NIL;
  mtSetMinOccurrence := NIL;
  mtGetMultipleRead := NIL;
  mtSetMultipleRead := NIL;
  mtGetNoiseReduction := NIL;
  mtSetNoiseReduction := NIL;
  mtGetPageNo := NIL;
  mtSetPageNo := NIL;
  mtGetPrefOccurrence := NIL;
  mtSetPrefOccurrence := NIL;
  mtGetQuietZoneSize := NIL;
  mtSetQuietZoneSize := NIL;
  mtGetRotation := NIL;
  mtSetRotation := NIL;
  mtGetUpperRatio := NIL;
  mtSetUpperRatio := NIL;
  mtGetReadCode39 := NIL;
  mtSetReadCode39 := NIL;
  mtGetReadEAN13 := NIL;
  mtSetReadEAN13 := NIL;
  mtGetReadEAN8 := NIL;
  mtSetReadEAN8 := NIL;
  mtGetReadUPCA := NIL;
  mtSetReadUPCA := NIL;
  mtGetReadUPCE := NIL;
  mtSetReadUPCE := NIL;
  mtGetShowCheckDigit := NIL;
  mtSetShowCheckDigit := NIL;
  mtGetReadCode128 := NIL;
  mtSetReadCode128 := NIL;
  mtGetCode39NeedStartStop := NIL;
  mtSetCode39NeedStartStop := NIL;
  mtGetReadCode25 := NIL;
  mtSetReadCode25 := NIL;
  mtGetColorThreshold := NIL;
  mtSetColorThreshold := NIL;
  mtGetColorProcessingLevel := NIL;
  mtSetColorProcessingLevel := NIL;
  mtGetBarString := NIL;
  mtScanBarCode := NIL;
  mtScanBarCodeFromBitmap := NIL;
  mtScanBarCodeFromDIB := NIL;
  mtGetBarStringType := NIL;
  mtGetBarStringPos := NIL;
  mtGetRawBarString := NIL;
  mtSetScanRect := NIL;
  mtGetReadPatchCodes := NIL;
  mtSetReadPatchCodes := NIL;

  { DT 09/06/04 }
  mtGetReadCodabar := NIL;
  mtSetReadCodabar := NIL;
  mtGetMaxLength := NIL;
  mtSetMaxLength := NIL;
  mtGetMinLength := NIL;
  mtSetMinLength := NIL;
  mtGetScanDirection := NIL;
  mtSetScanDirection := NIL;

  { AJB 7/6/05 }
  mtGetSkewTolerance := NIL;
  mtSetSkewTolerance := NIL;

  { Joe Skeen 3-May-2010 }
  mtGetBarCodeConfidence := NIL;
  mtGetReadDataMatrix := NIL;
  mtSetReadDataMatrix := NIL;
  mtGetReadPDF417 := NIL;
  mtSetReadPDF417 := NIL;
  mtGetConvertUPCEToEAN13 := NIL;
  mtSetConvertUPCEToEAN13 := nil;
  mtExportXMLSettings := nil;
  mtGetAllowDuplicateValues := nil;
  mtGetBarStringDirection := nil;
  mtGetCode25Checksum := nil;
  mtGetCode39Checksum := nil;
  mtGetDespeckle := nil;
  mtGetEncoding := nil;
  mtGetErrorCorrection := nil;
  mtGetExtendedCode39 := nil;
  mtGetGammaCorrection := nil;
  mtGetMedianFilter := nil;
  mtGetMinSeparation := nil;
  mtGetMinSpaceBarWidth := nil;
  mtGetPattern := nil;
  mtGetPdfBpp := nil;
  mtGetPdfDpi := nil;
  mtGetPhotometric := nil;
  mtGetReadCode25ni := nil;
  mtGetReadMicroPDF417 := nil;
  mtGetReadNumeric := nil;
  mtGetReadShortCode128 := nil;
  mtGetShortCode128MinLength := nil;
  mtGetSkewLineJump := nil;
  mtGetTifSplitMode := nil;
  mtGetTifSplitPath := nil;
  mtGetUseOverSampling := nil;
  mtLoadXMLSettings := nil;
  mtProcessXML := nil;
  mtSaveResults := nil;
  mtSetAllowDuplicateValues := nil;
  mtSetCode25Checksum := nil;
  mtSetCode39Checksum := nil;
  mtSetDespeckle := nil;
  mtSetEncoding := nil;
  mtSetErrorCorrection := nil;
  mtSetExtendedCode39 := nil;
  mtSetGammaCorrection := nil;
  mtSetMedianFilter := nil;
  mtSetMinSeparation := nil;
  mtSetMinSpaceBarWidth := nil;
  mtSetPattern := nil;
  mtSetPdfBpp := nil;
  mtSetPdfDpi := nil;
  mtSetPhotometric := nil;
  mtSetReadCode25ni := nil;
  mtSetReadMicroPDF417 := nil;
  mtSetReadNumeric := nil;
  mtSetReadShortCode128 := nil;
  mtSetShortCode128MinLength := nil;
  mtSetSkewLineJump := nil;
  mtSetTifSplitMode := nil;
  mtSetTifSplitPath := nil;
  mtSetUseOverSampling := nil;

  { AJB 7/6/05 }
  mtSetReadDatabar := nil;
  mtGetReadDatabar := nil;
  mtSetReadQRCode := nil;
  mtGetReadQRCode := nil;
  mtSetDatabarOptions := nil;
  mtGetDatabarOptions := nil;
  mtSetPdfImageOnly := nil;
  mtGetPdfImageOnly := nil;
  mtSetPdfImageExtractOptions := nil;
  mtGetPdfImageExtractOptions := nil;
  mtSetPdfImageRasterOptions := nil;
  mtGetPdfImageRasterOptions := nil;
  mtCreateBarcodeInstance := NIL;
  mtDestroyBarcodeInstance := nil;

  { AJB 2/10/2017 }
  mtGetBarcodesAtTopOfPage := nil;
  mtGetCode128Lenient := nil;
  mtGetDataMatrixAutoUTF8 := nil;
  mtGetPdf417AutoUTF8 := nil;
  mtGetPdf417Debug := nil;
  mtGetPdf417MacroEscapeBackslash := nil;
  mtGetQRCodeAutoMedianFilter := nil;
  mtGetQRCodeAutoUTF8 := nil;
  mtGetQrCodeReadInverted := nil;
  mtGetReadCode93 := nil;
  mtGetRotateBy45IfNoBarcode := nil;
  mtGetSkewedDatamatrix := nil;
  mtGetSkewedLinear := nil;
  mtGetUseFastScan := nil;
  mtGetUseOldCode128Algorithm := nil;
  mtGetUseRunCache := nil;
  mtGetWeightLongerBarcodes := nil;
  mtSetBarcodesAtTopOfPage := nil;
  mtSetCode128Lenient := nil;
  mtSetDataMatrixAutoUTF8 := nil;
  mtSetPdf417AutoUTF8 := nil;
  mtSetPdf417Debug := nil;
  mtSetPdf417MacroEscapeBackslash := nil;
  mtSetQRCodeAutoMedianFilter := nil;
  mtSetQRCodeAutoUTF8 := nil;
  mtSetQrCodeReadInverted := nil;
  mtSetReadCode93 := nil;
  mtSetRotateBy45IfNoBarcode := nil;
  mtSetSkewedDatamatrix := nil;
  mtSetSkewedLinear := nil;
  mtSetUseFastScan := nil;
  mtSetUseOldCode128Algorithm := nil;
  mtSetUseRunCache := nil;
  mtSetWeightLongerBarcodes := nil;
  mtGetBarCodeCount := nil;
  mtGetCode128DebugMode := nil;
  mtGetCode128SearchLevel := nil;
  mtGetCode39MaxRatioPcnt := nil;
  mtGetDataMatrixFinderGapTolerance := nil;
  mtGetFastScanLineJump := nil;
  mtGetMaxBarcodesPerPage := nil;
  mtGetMaxThreads := nil;
  mtGetMedianFilterBias := nil;
  mtGetPatchCodeMinOccurrence := nil;
  mtGetPdf417ChannelMode := nil;
  mtGetPdfLocking := nil;
  mtGetQuotedPrintableCharSet := nil;
  mtGetReportUnreadBarcodes := nil;
  mtGetShowCodabarStartStop := nil;
  mtGetBarStringPage := nil;
  mtGetBarStringQualityScore := nil;
  mtGetLastError := nil;
  mtGetLastWinError := nil;
  mtGetLicenseKey := nil;
  mtGetProgress := nil;
  mtGetScanExitCode := nil;
  mtGetTimeOut := nil;
  mtScanBarCodeAbort := nil;
  mtScanBarCodeInBackground := nil;
  mtScanBarCodeWait := nil;
  mtSetCode128DebugMode := nil;
  mtSetCode128SearchLevel := nil;
  mtSetCode39MaxRatioPcnt := nil;
  mtSetDataMatrixFinderGapTolerance := nil;
  mtSetFastScanLineJump := nil;
  mtSetMaxBarcodesPerPage := nil;
  mtSetMaxThreads := nil;
  mtSetMedianFilterBias := nil;
  mtSetPatchCodeMinOccurrence := nil;
  mtSetPdf417ChannelMode := nil;
  mtSetPdfLocking := nil;
  mtSetQuotedPrintableCharSet := nil;
  mtSetReportUnreadBarcodes := nil;
  mtSetShowCodabarStartStop := nil;
  mtSetTimeOut := nil;

  { AJB 16/04/2020 }
  mtGetPdfPassword := nil;
  mtSetPdfPassword := nil;
  mtGetDataMatrixSearchLevel := nil;
  mtSetDataMatrixSearchLevel := nil;
  mtGetDataMatrixRectangleSupport := nil;
  mtSetDataMatrixRectangleSupport := nil;
  mtGetReadEAN13Supplemental := nil;
  mtSetReadEAN13Supplemental := nil;
  mtGetDeskewMode := nil;
  mtSetDeskewMode := nil;
end;

initialization

finalization

DoneLibrary;

end.
